*====================================================================================================*
*                                  preparation_description.do                                                    *
*====================================================================================================*

*----------------------------------------------------------------------------------------------------*
*  Leopold 2018, replication files                                                         			 *
*  last update: 07 August 2018                                                                        *
*  data: soeplong 1984-2015, version 32.1, release 2017                                              *
*----------------------------------------------------------------------------------------------------*

*-----------------------------------------------------------------------------*
*  Get variables                                                              *
*-----------------------------------------------------------------------------*

* From main person file

use 	syear pid hid plh0174 plh0179 pli0038 pli0040 pli0043 pli0044	///
		pli0049 pli0051 plh0182 plh0175 plh0177 plh0178					///
		using "$data/pl.dta", clear
		
* From other files

merge 	m:1 pid using "$data\ppfad.dta", 	 		 						///
		keepusing (psample sex gebjahr germborn loc1989 erstbef letztbef) 	/// 
		keep (1 3) nogen
merge 	1:1 pid syear using "$data\pgen.dta", 		///
		keepusing (pgcasmin)	  					/// 
		keep (1 3) nogen
merge 	1:1 pid syear using "$data\pequiv.dta",   				///
		keepusing (d11106 d11107 d11105 i11102 h11101 y11101)   ///
		keep (1 3) nogen
merge 	1:1 pid syear using "$data\ppfadl.dta", 	///
		keepusing (partner) 						/// 
		keep (1 3) nogen
		

* Select sample

// Time use items are consistent from 1993 onwards
drop if syear < 1993

// Drop selective samples & oversamples (East Germans & immigrants)
drop if loc1989 != 2 	
drop if germborn != 1
keep if inlist(psample,1,2,3,4,5,6,8,10,11)


// Drop cohorts with too few observations
keep if inrange(gebjahr,1920,1989) 

// Drop ages with too few observations
gen  age = syear - gebj
keep if inrange(age,20,79) // drop ages with too few observations

// Drop if not head of HH or partner of head of HH
keep if inlist(d11105,1,2)

// Drop if partner status unclear
drop if partner == -1

		
* Prepare variables

// Define missings
foreach var of varlist * {
	replace `var' = . if `var' < 0
}

// Outcome: Satisfaction with housework
clonevar hsat = plh0174

// Age, cohort, and gender
egen agec = cut(age), at(20(5)80) // categorical age (for nonparametric plots)
egen coh = cut(gebjahr), at(1920(10)1990)
gen  male = sex == 1

// Partner in household
gen phh = .
replace phh = 1 if inlist(partner,1,2,3,4)
replace phh = 0 if inlist(partner,0)
drop if phh ==.

// Time use variables
rename pli0038 work
rename pli0040 errands
rename pli0043 housework
rename pli0044 childcare
rename pli0049 repairs
rename pli0051 leisure

// Housework hours = Routine housework + errands
gen hw = housework + errands

// Set extreme values to missing (impute later)
	foreach var of varlist work errands housework childcare repairs leisure hw {
		replace `var' = . if `var' > 12 & `var' < .
} 		

// Dummies for zero work hours and zero housework hours (for description & imputation model)
gen nowork = .
	replace nowork = 1 if work == 0
	replace nowork = 0 if work != . & work != 0
gen nohw = .
	replace nohw= 1 if hw == 0
	replace nohw = 0 if hw != . & hw != 0

//Income
gen einc = i11102 / (d11106^0.5) // equivalize by square root scale	
gen eincp = einc * (100/y11101)  // adjust for inflation (reference year 2011)
gen linc = log(eincp) 			 // take log to address right skew

// Attrition
gen left = letztbef < 2015
gen dur = letztbef - erstbef
replace dur = dur+1


* Table 1

tab agec coh


* Table 3 (Note: Table 2 comes later, after imputation)

gen m = hsat == .
egen pick = tag(pid)

// Share of missings among all obs of a respondent
bysort pid (syear): egen sm = mean(m) 

// Missing in all observations
gen am = sm == 1 

// Table 3 statistics
tabstat m nohw if sex == 2, by(coh) format(%9.2f)
tabstat m nohw if sex == 1, by(coh) format(%9.2f)
tabstat am if sex == 2 & pick == 1, by(coh) format(%9.2f)
tabstat am if sex == 1 & pick == 1, by(coh) format(%9.2f)
tabstat m if sex == 2 & hw !=. & hw != 0, by(coh) format(%9.2f)
tabstat m if sex == 1 & hw !=. & hw != 0, by(coh) format(%9.2f)
tabstat m if sex == 2 & hw == 0, by(coh) format(%9.2f)
tabstat m if sex == 1 & hw == 0, by(coh) format(%9.2f)


* Imputation

// Create cluster variables (within-person means)
foreach var of varlist 	hsat plh0175 plh0177 plh0178 plh0179 plh0182 nowork ///
						work errands nohw hw childcare repairs leisure ///
						linc d11107 syear ///
					   {
	bys pid (syear): egen clust_`var' = mean(`var')
}

// Set data structure
capt mi unset
mi set wide
mi set M = 20 // 20 imputations

// Dependent variables with missing values
mi register imputed hsat

// Additional predictors with missing values
mi register imputed plh0175 plh0177 plh0178 plh0179 plh0182 nowork 	   ///

					work errands nohw hw repairs leisure linc d11107 syear

// Cluster variables 
mi register imputed clust_* 

// Regular variables
mi register regular age coh phh male 

// Run the imputation model (Note: This can take hours to days; reduce number of imputations if necessary)
mi impute chained (pmm, knn(1)) hsat hw (regress) plh0175 plh0177 plh0178 plh0179 plh0182 nowork 	///
						work errands nohw repairs leisure linc syear d11107 clust_*  				///
					=   i.coh##i.phh c.age##c.age##c.age##c.age##i.phh 								///
						, rseed(123) by(male) replace report dots

// Compute total work hours
mi passive: gen th = hw + work


* Table 2

capture drop pick
egen pick = tag(pid)
sum age phh if sex == 1
sum age phh if sex == 2
mi estimate: mean hsat if sex == 1
mi estimate: mean hw if sex == 1
mi estimate: mean hsat if sex == 2
mi estimate: mean hw if sex == 2
tab coh if sex == 1 & pick == 1
tab coh if sex == 2 & pick == 1
sum dur left if pick == 1 & sex == 1
sum dur left if pick == 1 & sex == 2


* Examine total work hours

mi estimate: mean th if male
mi estimate: mean th if !male
foreach x of numlist 1920(10)1980 {
mi estimate: mean th if !male & coh == `x'
}
foreach x of numlist 1920(10)1980 {
mi estimate: mean th if male & coh == `x'
}


*-------------------------------------------------------------------------------------*
*-------------------------------------------------------------------------------------*

save "$posted/data.dta", replace

*-------------------------------------------------------------------------------------*
*-------------------------------------------------------------------------------------*

